@@ -43,7 +43,10 @@
 #define start_of_data() &etext
 #define start_of_text() ((char *)(sizeof(struct exec) + getpagesize()))
 
-#define UNIXSAVE "unexec-19.27.c"
+#define UNIXSAVE "unexec.c"
+#ifdef UNIXSAVE 
+ extern char *etext;
+#endif
 
 #define RELOC_FILE "rel_sun3.c"	/* for SFASL - enabled in bsd.h */
 
