@@ -29,6 +29,7 @@ char *alloc_contblock();
 char *alloc_relblock();
 object fSallocate_contiguous_pages();
 object fSallocate_relocatable_pages();
+
 /*  array.c  */
 enum aelttype Iarray_element_type();
 object fSaref1();
@@ -130,6 +131,7 @@ object simple_symlispcall_no_event();
 EXTER object Vevalhook;
 EXTER object Vapplyhook;
 object ieval();
+object ifuncall();
 object ifuncall1();
 object ifuncall2();
 object ifuncall3();
@@ -249,6 +251,7 @@ object append();
 object copy_list();
 object make_list();
 object nconc();
+object sublis1();
 
 /*  macros.c  */
 EXTER object sLAmacroexpand_hookA;
@@ -259,6 +262,7 @@ object macro_expand();
 EXTER char* system_directory;
 EXTER int ARGC;
 EXTER char **ARGV;
+void error();
 #ifdef UNIX
 EXTER char **ENVP;
 #endif
@@ -434,6 +438,7 @@ EXTER object sLAread_default_float_formatA;
 EXTER object sLAread_baseA;
 EXTER object sLAread_suppressA;
 EXTER object READtable;
+EXTER object read_byte1(); 
 EXTER int READdefault_float_format;
 EXTER int READbase;
 EXTER bool READsuppress;
@@ -441,7 +446,6 @@ EXTER object siSsharp_comma;
 EXTER bool escape_flag;
 EXTER object delimiting_char;
 EXTER bool detect_eos_flag;
-EXTER object read_byte1(); 
 /* bool in_list_flag; */
 EXTER bool dot_flag;
 EXTER bool preserving_whitespace_flag;
