@@ -69,6 +69,10 @@ typedef float shortfloat;
 typedef double longfloat;
 typedef unsigned short fatchar;
 
+#ifndef plong
+#define plong int
+#endif
+
 
 #define SIGNED_CHAR(x) (((char ) -1) < (char )0 ? (char) x \
 		  : (x >= (1<<(CHAR_SIZE-1)) ? \
@@ -99,7 +103,7 @@ struct fixnum_struct {
 	fixnum	FIXVAL;		/*  fixnum value  */
 };
 #define	Mfix(obje)	(obje)->FIX.FIXVAL
-#define fix Mfix
+#define fix(x) Mfix(x)
 
 #define	SMALL_FIXNUM_LIMIT	1024
 
@@ -114,18 +118,18 @@ struct shortfloat_struct {
 	shortfloat	SFVAL;	/*  shortfloat value  */
 };
 #define	Msf(obje)	(obje)->SF.SFVAL
-#define sf Msf
+#define sf(x) Msf(x)
 
 struct longfloat_struct {
 			FIRSTWORD;
 	longfloat	LFVAL;	/*  longfloat value  */
 };
 #define	Mlf(obje)	(obje)->LF.LFVAL
-#define lf Mlf
+#define lf(x) Mlf(x)
 
 struct bignum {
 			FIRSTWORD;
-	long             *big_self;	/*  bignum body  */
+	plong             *big_self;	/*  bignum body  */
 	int		big_length;	/*  bignum length  */
 };
 
@@ -172,21 +176,20 @@ enum stype {			/*  symbol type  */
 #define	Ct			((object)&Ct_body)
 #define sLnil Cnil
 #define sLt Ct
+
+#define	NOT_SPECIAL		((int (*)())Cnil)
+#define	s_fillp		st_fillp
+#define	s_self		st_self
+
 struct symbol {
 		FIRSTWORD;
 	object	s_dbind;	/*  dynamic binding  */
 	int	(*s_sfdef)();	/*  special form definition  */
 				/*  This field coincides with c_car  */
-
-#define	NOT_SPECIAL		((int (*)())Cnil)
-
-#define	s_fillp		st_fillp
-#define	s_self		st_self
-
-	int	s_fillp;	/*  print name length  */
 	char	*s_self;	/*  print name  */
 				/*  These fields coincide with  */
 				/*  st_fillp and st_self.  */
+	int	s_fillp;	/*  print name length  */
 
 	object	s_gfdef;        /*  global function definition  */
 				/*  For a macro,  */
@@ -269,7 +272,7 @@ enum aelttype {			/*  array element type  */
 	aet_bit,		/*  bit  */
 	aet_fix,		/*  fixnum  */
 	aet_sf,			/*  short-float  */
-	aet_lf,			/*  long-float  */
+	aet_lf,			/*  plong-float  */
 	aet_char,               /* signed char */
         aet_uchar,               /* unsigned char */
 	aet_short,              /* signed short */
@@ -279,73 +282,85 @@ enum aelttype {			/*  array element type  */
 
 struct array {			/*  array header  */
 		FIRSTWORD;
+	object	a_displaced;	/*  displaced  */
 	short	a_rank;		/*  array rank  */
-/*	short	v_hasfillp;	    has-fill-pointer flag  */
+	short	a_elttype;	/*  element type  */
+	object	*a_self;	/*  pointer to the array  */
 	short	a_adjustable;	/*  adjustable flag  */
+	short	a_offset;	/*  bitvector offset  */
 	int	a_dim;		/*  dimension  */
 	int	*a_dims;	/*  table of dimensions  */
-/*	int	v_fillp;	    fill pointer  */
-	object	*a_self;	/*  pointer to the array  */
-	object	a_displaced;	/*  displaced  */
-	short	a_elttype;	/*  element type  */
-	short	a_offset;	/*  bitvector offset  */
+
 };
 
 
 
 struct vector {			/*  vector header  */
 		FIRSTWORD;
+	object	v_displaced;	/*  displaced  */
 	short	v_hasfillp;	/*  has-fill-pointer flag  */
-	short	v_adjustable;	/*  adjustable flag  */
-	int	v_dim;		/*  dimension  */
+	short	v_elttype;	/*  element type  */
+		
+	object	*v_self;	/*  pointer to the vector  */
 	int	v_fillp;	/*  fill pointer  */
 				/*  For simple vectors,  */
 				/*  v_fillp is equal to v_dim.  */
-	object	*v_self;	/*  pointer to the vector  */
-	object	v_displaced;	/*  displaced  */
-	short	v_elttype;	/*  element type  */
+	int	v_dim;		/*  dimension  */
+	short	v_adjustable;	/*  adjustable flag  */
 	short	v_offset;	/*  not used  */
 };
 
 struct string {			/*  string header  */
 		FIRSTWORD;
+	object	st_displaced;	/*  displaced  */
 	short	st_hasfillp;	/*  has-fill-pointer flag  */
 	short	st_adjustable;	/*  adjustable flag  */
-	int	st_dim;		/*  dimension  */
-				/*  string length  */
+	char	*st_self;	/*  pointer to the string  */
 	int	st_fillp;	/*  fill pointer  */
 				/*  For simple strings,  */
 				/*  st_fillp is equal to st_dim.  */
-	char	*st_self;	/*  pointer to the string  */
-	object	st_displaced;	/*  displaced  */
+	int	st_dim;		/*  dimension  */
+				/*  string length  */
+
 };
 
 struct ustring {
 		FIRSTWORD;
-	short	ust_hasfillp;
-	short	ust_adjustable;
-	int	ust_dim;
-	int	ust_fillp;
-	unsigned char
-		*ust_self;
 	object	ust_displaced;
+	short	ust_hasfillp;
+	short	ust_adjustable;		
+	unsigned char *ust_self;
+	int	ust_fillp;
+
+	int	ust_dim;
+
+
 };
 
 #define USHORT(x,i) (((unsigned short *)(x)->ust.ust_self)[i])
 #define SHORT(x,i) ((( short *)(x)->ust.ust_self)[i])
 
+#define BV_OFFSET(x) ((type_of(x)==t_bitvector ? x->bv.bv_offset : \
+		       type_of(x)== t_array ? x->a.a_offset : abort()))
+
+#define SET_BV_OFFSET(x,val) ((type_of(x)==t_bitvector ? x->bv.bv_offset = val : \
+		       type_of(x)== t_array ? x->a.a_offset=val : abort()))
+
+
+		       
+
 struct bitvector {		/*  bitvector header  */
 		FIRSTWORD;
+	object	bv_displaced;	/*  displaced  */
 	short	bv_hasfillp;	/*  has-fill-pointer flag  */
-	short	bv_adjustable;	/*  adjustable flag  */
-	int	bv_dim;		/*  dimension  */
-				/*  number of bits  */
+	short	bv_elttype;	/*  not used  */
+	char	*bv_self;	/*  pointer to the bitvector  */
 	int	bv_fillp;	/*  fill pointer  */
 				/*  For simple bitvectors,  */
 				/*  st_fillp is equal to st_dim.  */
-	char	*bv_self;	/*  pointer to the bitvector  */
-	object	bv_displaced;	/*  displaced  */
-	short	bv_elttype;	/*  aet_bit  */
+	int	bv_dim;		/*  dimension  */
+				/*  number of bits  */
+	short	bv_adjustable;	/*  adjustable flag  */
 	short	bv_offset;	/*  bitvector offset  */
 				/*  the position of the first bit  */
 				/*  in the first byte  */
@@ -353,40 +368,47 @@ struct bitvector {		/*  bitvector header  */
 
 struct fixarray {		/*  fixnum array header  */
 		FIRSTWORD;
+	object	fixa_displaced;	/*  displaced  */
 	short	fixa_rank;	/*  array rank  */
+	short	fixa_elttype;	/*  element type  */
+	fixnum	*fixa_self;	/*  pointer to the array  */
 	short	fixa_adjustable;/*  adjustable flag  */
+	short	fixa_offset;	/*  not used  */
 	int	fixa_dim;	/*  dimension  */
 	int	*fixa_dims;	/*  table of dimensions  */
-	fixnum	*fixa_self;	/*  pointer to the array  */
-	object	fixa_displaced;	/*  displaced  */
-	short	fixa_elttype;	/*  element type  */
-	short	fixa_offset;	/*  not used  */
+
 };
 
 struct sfarray {		/*  short-float array header  */
 		FIRSTWORD;
+	object	sfa_displaced;	/*  displaced  */
 	short	sfa_rank;	/*  array rank  */
-	short	sfa_adjustable;	/*  adjustable flag  */
-	int	sfa_dim;	/*  dimension  */
-	int	*sfa_dims;	/*  table of dimensions  */
+	short	sfa_elttype;	/*  element type  */
 	shortfloat
 		*sfa_self;	/*  pointer to the array  */
-	object	sfa_displaced;	/*  displaced  */
-	short	sfa_elttype;	/*  element type  */
+	short	sfa_adjustable;	/*  adjustable flag  */
 	short	sfa_offset;	/*  not used  */
+	int	sfa_dim;	/*  dimension  */
+
+	int	*sfa_dims;	/*  table of dimensions  */
+
+
+
 };
 
-struct lfarray {		/*  long-float array header  */
+struct lfarray {		/*  plong-float array header  */
 		FIRSTWORD;
+	object	lfa_displaced;	/*  displaced  */
 	short	lfa_rank;	/*  array rank  */
-	short	lfa_adjustable;	/*  adjustable flag  */
-	int	lfa_dim;		/*  dimension  */
-	int	*lfa_dims;	/*  table of dimensions  */
+	short	lfa_elttype;	/*  element type  */
 	longfloat
 		*lfa_self;	/*  pointer to the array  */
-	object	lfa_displaced;	/*  displaced  */
-	short	lfa_elttype;	/*  element type  */
+	short	lfa_adjustable;	/*  adjustable flag  */
 	short	lfa_offset;	/*  not used  */
+	int	lfa_dim;		/*  dimension  */
+	int	*lfa_dims;	/*  table of dimensions  */
+
+
 };
 
 struct structure {		/*  structure header  */
@@ -581,7 +603,7 @@ union lispunion {
 	struct shortfloat_struct
 			SF;	/*  short floating-point number  */
 	struct longfloat_struct
-			LF;	/*  long floating-point number  */
+			LF;	/*  plong floating-point number  */
 	struct complex	cmp;	/*  complex number  */
 	struct character
 			ch;	/*  character  */
@@ -615,17 +637,26 @@ union lispunion {
 
 	struct fixarray	fixa;	/*  fixnum array  */
 	struct sfarray	sfa;	/*  short-float array  */
-	struct lfarray	lfa;	/*  long-float array  */
+	struct lfarray	lfa;	/*  plong-float array  */
 };
 
+#define address_int unsigned int
+
 /*
 	The struct of free lists.
 */
 struct freelist {
 	FIRSTWORD;
-	object f_link;
+	address_int f_link;
 };
-#define FL_LINK(ad) (((struct freelist *)(ad))->f_link)
+#ifndef INT_TO_ADDRESS
+#define INT_TO_ADDRESS(x) ((object )(long )x)
+#endif
+
+#define F_LINK(x) ((struct freelist *)(long) x)->f_link
+#define FL_LINK F_LINK
+#define SET_LINK(x,val) F_LINK(x) = (address_int) (val)
+#define OBJ_LINK(x) ((object) INT_TO_ADDRESS(F_LINK(x)))
 
 #define	FREE	(-1)		/*  free object  */
 
@@ -724,12 +755,13 @@ char *tmp_alloc;
    */
 
 #define ALLOC_ALIGNED(f, size,align) \
-  (align <= sizeof(long) ? (char *)((f)(size)) : \
+  (align <= sizeof(plong) ? (char *)((f)(size)) : \
    (tmp_alloc = (char *)((f)(size+(size ?(align)-1 : 0)))+(align)-1 , \
    (char *)(align * (((unsigned int)tmp_alloc)/align))))
 #define AR_ALLOC(f,n,type) (type *) \
   (ALLOC_ALIGNED(f,(n)*sizeof(type),sizeof(type)))
 
+
 #ifndef HOLEPAGE
 #define	HOLEPAGE	128
 #endif
@@ -804,7 +836,7 @@ EXTER object MVloc[10];
  object Xxvl[65]; \
  {int i; \
   new=Xxvl; \
-  if (n >= 65) FEerror("Too long vl"); \
+  if (n >= 65) FEerror("Too plong vl"); \
   for (i=0 ; i < (n); i++) new[i]=va_arg(vl,object);}
 #endif
 #define make_si_vfun(s,f,min,max) \
@@ -833,9 +865,11 @@ EXTER struct call_data fcall;
 #define RETURNI(n,val1,listvals) RETURN(n,int,val1,listvals)
 #define RETURNO(n,val1,listvals) RETURN(n,object,val1,listvals)
 
+/* eg: RETURN(3,object,val1,(RV(val2),RV(val3))) */
 #define RETURN(n,typ,val1,listvals) \
    do{typ _val1 = val1; object *_p=&fcall.values[1]; listvals; fcall.nvalues= n; return _val1;}while(0)
-#define FUNCALL(n,form) (VFUN_NARGS=n,form)
+/* #define CALL(n,form) (VFUN_NARGS=n,form) */
+
 	
 
 /* we sometimes have to touch the header of arrays or structures
@@ -866,7 +900,7 @@ EXTER object sSlambda_block_expanded;
 #define CHECK_INTERRUPT   if (signals_pending) raise_pending_signals(sig_safe)
 
 #define BEGIN_NO_INTERRUPT \
- long old_signals_allowed = signals_allowed; \
+ plong old_signals_allowed = signals_allowed; \
   signals_allowed = 0
 
 #define END_NO_INTERRUPT \
@@ -883,5 +917,5 @@ EXTER object sSlambda_block_expanded;
 
 void raise_pending_signals();
 
-EXTER unsigned long signals_allowed, signals_pending  ;
+EXTER unsigned plong signals_allowed, signals_pending  ;
 
