@@ -43,8 +43,6 @@
 				    } while(0)
 
 
-
-
 #define USE_ATT_TIME
 
 #define GETCWD
@@ -121,6 +119,17 @@ do {static struct sigaction action; \
 /* End for cmpinclude */
 
 /* Sun 4.1 needs to have some cached yp stuff undone at save time */
+#ifdef IN_SFASL
+#include <sys/types.h>
+#include <sys/mman.h>
+/* we have to make the pages executable */
+#define CLEAR_CACHE do { unsigned long ps = getpagesize(); \
+			 char *beg = (unsigned long )(memory->cfd.cfd_start) & ~(ps-1); \
+			 char *end =  ROUND_UP(memory->cfd.cfd_start + \
+				          memory->cfd.cfd_size,ps); \
+			   mprotect(beg,end-beg,PROT_READ|PROT_WRITE|PROT_EXEC);} while(0)
+				   
+#endif
 
 #define HAVE_YP_UNBIND
 #undef  MAXPAGE 
