@@ -30,7 +30,7 @@ T7:;
 	base[0]= (V2);
 	base[1]= VV[1];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk16)();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T10;}
@@ -47,7 +47,7 @@ T18:;
 	base[1]= (V2);
 	base[2]= (V7);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk16)();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T22;}
@@ -76,7 +76,7 @@ T41:;
 	base[1]= (V2);
 	base[2]= (V13);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk16)();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T45;}
@@ -1077,111 +1077,125 @@ T341:;
 	V193= ON_STACK_CONS((V194),(V193));
 	V193= ON_STACK_CONS(VV[8],(V193));
 T360:;
-	{register object V204;
+	{register object x= VV[14],V204= (V193);
+	while(!endp(V204))
+	if(type_of(V204->c.c_car)==t_cons &&eql(x,V204->c.c_car->c.c_car)){
+	goto T366;
+	}else V204=V204->c.c_cdr;}
+	base[0]= (V191);
+	vs_top=(vs_base=base+0)+1;
+	(void) (*Lnk30)();
+	vs_top=sup;
+	V205= vs_base[0];
+	V193= ON_STACK_CONS(V205,(V193));
+	V193= ON_STACK_CONS(VV[14],(V193));
+T366:;
+	{register object V206;
 	base[0]= (V192);
-	base[1]= VV[14];
+	base[1]= VV[15];
 	base[2]= Ct;
-	{object V205;
-	V205= (V193);
+	{object V207;
+	V207= (V193);
 	 vs_top=base+3;
-	 while(!endp(V205))
-	 {vs_push(car(V205));V205=cdr(V205);}
+	 while(!endp(V207))
+	 {vs_push(car(V207));V207=cdr(V207);}
 	vs_base=base+0;}
 	(void) (*Lnk27)();
 	vs_top=sup;
-	V204= vs_base[0];
+	V206= vs_base[0];
 	if((cdr((V192)))==Cnil){
-	goto T372;}
-	V206= cdr((V192));
-	V207= (*(LnkLI30))((V191));
-	if(!(equal(/* INLINE-ARGS */V206,cdr(/* INLINE-ARGS */V207)))){
-	goto T373;}
-	if(!(((V194))==(VV[15]))){
-	goto T372;}
+	goto T380;}
+	V208= cdr((V192));
+	V209= (*(LnkLI31))((V191));
+	if(!(equal(/* INLINE-ARGS */V208,cdr(/* INLINE-ARGS */V209)))){
+	goto T381;}
+	if(!(((V194))==(VV[16]))){
+	goto T380;}
 	base[0]= (V192);
 	vs_top=(vs_base=base+0)+1;
 	Llast();
 	vs_top=sup;
-	V208= vs_base[0];
-	{int V209= fix(car(V208));
-	if(!((0)==((V209>=0&&(8)>0?(V209)%(8):imod(V209,8))))){
-	goto T373;}}
-T372:;
+	V210= vs_base[0];
+	{int V211= fix(car(V210));
+	if(!((0)==((V211>=0&&(8)>0?(V211)%(8):imod(V211,8))))){
+	goto T381;}}
+T380:;
 	base[0]= (V191);
-	base[1]= (V204);
+	base[1]= (V206);
 	base[2]= small_fixnum(0);
 	base[3]= small_fixnum(0);
-	base[5]= (V204);
+	base[5]= (V206);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk31)();
-	vs_top=sup;
-	V210= vs_base[0];
-	base[5]= (V191);
-	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk31)();
-	vs_top=sup;
-	V211= vs_base[0];
-	base[4]= (number_compare(V210,V211)<=0?(V210):V211);
-	vs_top=(vs_base=base+0)+5;
 	(void) (*Lnk32)();
 	vs_top=sup;
-	goto T371;
-T373:;
-	{register object V212;
+	V212= vs_base[0];
+	base[5]= (V191);
+	vs_top=(vs_base=base+5)+1;
+	(void) (*Lnk32)();
+	vs_top=sup;
+	V213= vs_base[0];
+	base[4]= (number_compare(V212,V213)<=0?(V212):V213);
+	vs_top=(vs_base=base+0)+5;
+	(void) (*Lnk33)();
+	vs_top=sup;
+	goto T379;
+T381:;
+	{register object V214;
 	base[0]= make_fixnum(length((V192)));
 	base[1]= VV[7];
 	base[2]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+3;
 	Lmake_list();
 	vs_top=sup;
-	V212= vs_base[0];
-T397:;
+	V214= vs_base[0];
+T405:;
 	base[0]= (V191);
-	{object V213;
-	V213= (V212);
+	{object V215;
+	V215= (V214);
 	 vs_top=base+1;
-	 while(!endp(V213))
-	 {vs_push(car(V213));V213=cdr(V213);}
+	 while(!endp(V215))
+	 {vs_push(car(V215));V215=cdr(V215);}
 	vs_base=base+0;}
-	(void) (*Lnk33)();
+	(void) (*Lnk34)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T400;}
-	base[0]= (V204);
+	goto T408;}
+	base[0]= (V206);
 	base[2]= (V191);
-	{object V214;
-	V214= (V212);
+	{object V216;
+	V216= (V214);
 	 vs_top=base+3;
-	 while(!endp(V214))
-	 {vs_push(car(V214));V214=cdr(V214);}
+	 while(!endp(V216))
+	 {vs_push(car(V216));V216=cdr(V216);}
 	vs_base=base+2;}
 	Laref();
 	vs_top=sup;
 	base[1]= vs_base[0];
-	base[2]= (V212);
+	base[2]= (V214);
 	vs_top=(vs_base=base+0)+3;
 	(void) (*Lnk25)();
 	vs_top=sup;
-T400:;
-	if(((*(LnkLI26))((V212),(V192)))==Cnil){
-	goto T410;}
-	goto T371;
-T410:;
-	goto T397;}
-T371:;
+T408:;
+	if(((*(LnkLI26))((V214),(V192)))==Cnil){
+	goto T418;}
+	goto T379;
+T418:;
+	goto T405;}
+T379:;
 	base[0]= (V191);
-	base[1]= (V204);
+	base[1]= (V206);
 	vs_top=(vs_base=base+0)+2;
 	siLreplace_array();
 	vs_top=sup;
-	{object V215 = vs_base[0];
-	VMR25(V215)}}}
+	{object V217 = vs_base[0];
+	VMR25(V217)}}}
 	}}
-static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* ARRAY-IN-BOUNDS-P */
-static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* COPY-ARRAY-PORTION */
-static LnkT31(){ call_or_link(VV[31],&Lnk31);} /* ARRAY-TOTAL-SIZE */
-static object  LnkTLI30(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[30],&LnkLI30,1,ap);} /* ARRAY-DIMENSIONS */
+static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* ARRAY-IN-BOUNDS-P */
+static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* COPY-ARRAY-PORTION */
+static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* ARRAY-TOTAL-SIZE */
+static object  LnkTLI31(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[31],&LnkLI31,1,ap);} /* ARRAY-DIMENSIONS */
 static LnkT27(){ call_or_link(VV[27],&Lnk27);} /* MAKE-ARRAY */
+static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* STATICP */
 static LnkT29(){ call_or_link(VV[29],&Lnk29);} /* ARRAY-HAS-FILL-POINTER-P */
 static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[28],&LnkLI28,ap);} /* ADJUST-ARRAY */
 static object  LnkTLI27(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[27],&LnkLI27,ap);} /* MAKE-ARRAY */
@@ -1191,4 +1205,9 @@ static object  LnkTLI24(va_alist)va_dcl{va_list ap;va_start(ap);return(object )c
 static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* MAKE-ARRAY1 */
 static LnkT22(){ call_or_link(VV[22],&Lnk22);} /* GET-AELTTYPE */
 static object  LnkTLI21(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[21],&LnkLI21,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
-static LnkT16(){ call_or_link(VV[16],&Lnk16);} /* SUBTYPEP */
+static LnkT17(){ call_or_link(VV[17],&Lnk17);} /* SUBTYPEP */
+
+#ifdef SYSTEM_SPECIAL_INIT
+SYSTEM_SPECIAL_INIT
+#endif
+
