@@ -1,4 +1,5 @@
 
+
 /*          Copyright (C) 1994 W. Schelter
 
 This file is part of GNU Common Lisp, herein referred to as GCL
@@ -38,9 +39,10 @@ Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
      
 */  
 
+#include "include.h"
 
 int bfffo(x)
-     unsigned long x;
+     unsigned plong x;
 {
   int sc;
   static int tabshi[16]={4,3,2,2,1,1,1,1,0,0,0,0,0,0,0,0};
