@@ -114,6 +114,11 @@ eg to add 20 more do (si::set-hole-size %d %d)\n...start over ", new_holepage, 2
 		       }
 		}
 		holepage -= n;
+		if (heap_end == core_end)
+		  /* can happen when mallocs occur before rel block set up..*/
+		  { sbrk(PAGESIZE*n) ;
+		    core_end += PAGESIZE*n;
+		  }
 		heap_end += PAGESIZE*n;
 		return(e);
 	}
@@ -174,7 +179,7 @@ add_page_to_freelist(p,tm)
  fw= *(int *)x;
  while (--i >= 0)
    { *(int *)x=fw;
-     F_LINK(x)=f;
+     SET_LINK(x,f);
      f=x;
      x= (object) ((char *)x + size);
    }
@@ -229,7 +234,7 @@ ONCE_MORE:
 		if (tm->tm_npage >= tm->tm_maxpage)
 			goto CALL_GBC;
 	}
-	tm->tm_free = ((struct freelist *)obj)->f_link;
+	tm->tm_free = OBJ_LINK(obj);
 	--(tm->tm_nfree);
 	(tm->tm_nused)++;
 	obj->d.t = (short)t;
@@ -308,7 +313,7 @@ ONCE_MORE:
 		if (tm->tm_npage >= tm->tm_maxpage)
 			goto CALL_GBC;
 	}
-	tm->tm_free = ((struct freelist *)obj)->f_link;
+	tm->tm_free = OBJ_LINK(obj);
 	--(tm->tm_nfree);
 	(tm->tm_nused)++;
 	obj->c.t = (short)t_cons;
@@ -396,7 +401,6 @@ DEFUN("RESET-NUMBER-USED",object,fSreset_number_used,SI,0,1,NONE,OO,OO,OO,OO,"")
   RETURN1(sLnil);
 }
 
-#define	round_up(n)	(((n) + 03) & ~03)
 
 char *
 alloc_contblock(n)
@@ -414,7 +418,7 @@ int n;
 */
 
 	g = FALSE;
-	n = round_up(n);
+	n = ROUND_UP_PTR(n);
 
 ONCE_MORE:
 	 CHECK_INTERRUPT;
@@ -501,7 +505,7 @@ int n;
 */
 
 	g = FALSE;
-	n = round_up(n);
+	n = ROUND_UP_PTR(n);
 
 ONCE_MORE:
         CHECK_INTERRUPT;
@@ -580,8 +584,8 @@ int elsize, nelts;
 		return;
 	}
 	tm_table[(int)t].tm_type = t;
-	tm_table[(int)t].tm_size = round_up(elsize);
-	tm_table[(int)t].tm_nppage = PAGESIZE/round_up(elsize);
+	tm_table[(int)t].tm_size = ROUND_UP_PTR(elsize);
+	tm_table[(int)t].tm_nppage = PAGESIZE/ROUND_UP_PTR(elsize);
 	tm_table[(int)t].tm_free = OBJNULL;
 	tm_table[(int)t].tm_nfree = 0;
 	tm_table[(int)t].tm_nused = 0;
@@ -615,7 +619,7 @@ set_maxpage()
   
 SET_REAL_MAXPAGE;
 
-      }
+}
 
 
 
@@ -629,6 +633,7 @@ init_alloc()
 	enum type t;
 	int c;
 	static initialized;
+
 	if (initialized) return;
 	initialized=1;
 	
@@ -648,11 +653,26 @@ init_alloc()
 
 	set_maxpage();
 
+#ifdef __linux__
+	/* Some versions of the Linux startup code are broken.
+	   For these, the first call to sbrk() fails, but
+	   subsequent calls are o.k.
+	   */
+	if ( (int)sbrk(0) == -1 )
+	  {
+	    if ( (int)sbrk(0) == -1 )
+	      {
+		fputs("FATAL Linux sbrk() error\n", stderr);
+		exit(1);
+	      }
+	    fputs("WARNING: Non-fatal Linux sbrk() error\n", stderr);
+	  }
+#endif
 
 	INIT_ALLOC;
 	
-
 	alloc_page(-(holepage + nrbpage));
+
 	rb_start = rb_pointer = heap_end + PAGESIZE*holepage;
 	rb_end = rb_start + PAGESIZE*nrbpage;
 	rb_limit = rb_end - 2*RB_GETA;
@@ -675,7 +695,7 @@ init_alloc()
 	init_tm(t_bignum, "BBIGNUM", sizeof(struct bignum), 2730,0 );
 	init_tm(t_ratio, "RRATIONAL", sizeof(struct ratio), 170,0 );
 	init_tm(t_shortfloat, "FSHORT-FLOAT",
-		sizeof(struct shortfloat_struct), 256 ,0);
+		sizeof(struct shortfloat_struct), 256 ,1);
 	init_tm(t_longfloat, "LLONG-FLOAT",
 		sizeof(struct longfloat_struct), 170 ,0);
 	init_tm(t_complex, "CCOMPLEX", sizeof(struct complex), 170 ,0);
@@ -699,7 +719,6 @@ init_alloc()
 	init_tm(t_contiguous, "_CONTIGUOUS-BLOCKS", 1001,0,20);
 	tm_table[t_relocatable].tm_nppage = PAGESIZE;
 	tm_table[t_contiguous].tm_nppage = PAGESIZE;
-	
 
 
 	ncb = 0;
@@ -739,7 +758,8 @@ va_dcl
 	CHECK_ARG_RANGE(2,3);
 	t= t_from_type(type);
 	if  (npages <= 0)
-		FEerror("Allocate takes positive argument.", 1, npages);
+		FEerror("Allocate takes positive argument.", 1,
+			make_fixnum(npages));
 	tm = tm_of(t);
 	if (tm->tm_npage > npages) {npages=tm->tm_npage;}
 	tm->tm_maxpage = npages;
@@ -759,7 +779,8 @@ ALLOCATE:
 	  
 	if (available_pages < tm->tm_maxpage - tm->tm_npage ||
 	    (pp = alloc_page(tm->tm_maxpage - tm->tm_npage)) == NULL) {
-	FEerror("Can't allocate ~D pages for ~A.", 2, npages, (make_simple_string(tm->tm_name+1)));
+	FEerror("Can't allocate ~D pages for ~A.", 2,
+		make_fixnum(npages), (make_simple_string(tm->tm_name+1)));
 	}
 	    for (;  tm->tm_npage < tm->tm_maxpage;  pp += PAGESIZE)
 	      add_page_to_freelist(pp,tm);}
@@ -779,7 +800,7 @@ t_from_type(type)
       0==strncmp((tm->tm_name)+1,type->st.st_self,type->st.st_fillp)
       )
      return i;}
- FEerror("Unrecognized type");
+ FEerror("Unrecognized type",0);
 }
 /* When sgc is enabled the TYPE should have at least MIN pages of sgc type,
    and at most MAX of them.   Each page should be FREE_PERCENT free
@@ -864,7 +885,7 @@ va_dcl
 	m = maxcbpage - ncbpage;
 	if (available_pages < m || (p = alloc_page(m)) == NULL)
 		FEerror("Can't allocate ~D pages for contiguous blocks.",
-			1, npages);
+			1, make_fixnum(npages));
 	{int i ;
 	for (i = 0;  i < m;  i++)
 		type_map[page(p + PAGESIZE*i)] = (char)t_contiguous;
@@ -1073,6 +1094,12 @@ int size;
 }
 
 #endif /* gnumalloc */
+
+DEFUN("STATICP",object,fSstaticp,SI,1,1,NONE,OO,OO,OO,OO,"Tell if the string or vector is static") (x)
+object x;
+{ RETURN1((inheap(x->ust.ust_self) ? sLt : sLnil));
+}
+
 char *
 calloc(nelem, elsize)
 int nelem, elsize;
@@ -1086,6 +1113,7 @@ int nelem, elsize;
 	return(ptr);
 }
 
+
 cfree(ptr)
 char *ptr;
 {
