@@ -101,7 +101,7 @@ quick_call_sfun(fun)
   vs_base[0]=
     (restype==f_object ?  res :
      restype==f_fixnum ? make_fixnum((int)res)
-     :(object) FEerror("Bad result type"));
+     :(object) FEerror("Bad result type",0));
   vs_top=vs_base+1;
   CHECK_AVMA;
   return;}
@@ -1399,7 +1399,7 @@ int i=fcall.argd;
     case 1: *(base++)=va_arg(ap,object);
     case 0: break;
     default:
-      FEerror(0,"bad args");
+      FEerror("bad args",0);
     } vs_top=base;
       base=base -i;
   	do{object fun=fcall.fun;
@@ -1493,7 +1493,7 @@ va_dcl
       case 1: *(base++)=va_arg(ap,object);
       case 0: break;
       default:
-	FEerror(0,"bad args");
+	FEerror("bad args",0);
       }  vs_top=base;
       base=base -i;
       (*fcall.fun->cf.cf_self)();
