@@ -57,7 +57,6 @@ int sgc_enabled=0;
 int  first_protectable_page =0;
 
 
-#define	round_up(n)	(((n) + 03) & ~03)
 
 char *copy_relblock();
 
@@ -80,9 +79,6 @@ struct apage {
 	char apage_self[PAGESIZE];
 };
 
-
-#define	inheap(pp)	((char *)(pp) < heap_end)
-
 int maxpage;
 
 object sSAnotify_gbcA;
@@ -392,6 +388,13 @@ BEGIN:
 			goto CASE_SPECIAL;
 
         case t_bignum:
+#ifdef SDEBUG
+		if (type_map[page(x->big.big_self)] < t_contiguous)
+		  {
+		    printf("bad body for %x (%x)\n",x,cp);
+		    
+		  }
+#endif 		
 		if ((int)what_to_collect >= (int)t_contiguous) {
 		  j = x->big.big_length;
 		  cp = (char *)(x->big.big_self);
@@ -409,8 +412,8 @@ BEGIN:
 		  if (inheap(cp)) {
 		    if (what_to_collect == t_contiguous)
 		      mark_contblock(cp, j);
-		  } else 
-		    x->big.big_self = (long *) copy_relblock(cp, j);}
+		  } else{
+		       x->big.big_self = (plong *) copy_relblock(cp, j);}}
 		break;
 
 	CASE_STRING:
@@ -444,7 +447,7 @@ BEGIN:
 
 #define W_SIZE (8*sizeof(int))
 		j= sizeof(int) *
-		   ((x->bv.bv_offset + x->bv.bv_dim + W_SIZE -1)/W_SIZE);
+		   ((BV_OFFSET(x) + x->bv.bv_dim + W_SIZE -1)/W_SIZE);
 		cp = x->bv.bv_self;
 		if (cp == NULL)
 			break;
@@ -558,7 +561,7 @@ BEGIN:
 
         case t_closure:
        { int i ;
-         if (what_to_collect >= t_contiguous)
+         if (what_to_collect == t_contiguous)
               mark_contblock(x->cc.cc_turbo,x->cc.cc_envdim);
          for (i= 0 ; i < x->cc.cc_envdim ; i++) {
 	   mark_object(x->cc.cc_turbo[i]);}}
@@ -834,7 +837,8 @@ sweep_phase()
 				 }
 			}
 			*/
-			((struct freelist *)x)->f_link = f;
+/*			((struct freelist *)x)->f_link = f; */
+			SET_LINK(x,f);
 			x->d.m = FREE;
 			f = x;
 			k++;
@@ -874,19 +878,19 @@ contblock_sweep_phase()
 		e = pagetochar(j);
 		for (p = s;  p < e;) {
 			if (get_mark_bit((int *)p)) {
-				p += 4;
+				p += PTR_ALIGN;
 				continue;
 			}
-			q = p + 4;
+			q = p + PTR_ALIGN;
 			while (q < e) {
 				if (!get_mark_bit((int *)q)) {
-					q += 4;
+					q += PTR_ALIGN;
 					continue;
 				}
 				break;
 			}
 			insert_contblock(p, q - p);
-			p = q + 4;
+			p = q + PTR_ALIGN;
 		}
 		i = j + 1;
 	}
@@ -1000,8 +1004,16 @@ enum type t;
 		else
 			rb_start1 = rb_start;
 
-		rb_pointer = rb_start;
-		rb_pointer1 = rb_start1;
+		/* as we walk through marking data, we replace the
+		   relocatable pointers
+		   in objects by the rb_pointer, advance that
+		   by the size, and copy the actual
+		   data there to rb_pointer1, and advance it by the size
+		   at the end [rb_start1,rb_pointer1] is copied
+		   to [rb_start,rb_pointer]
+		   */
+		rb_pointer = rb_start;  /* where the new relblock will start */
+		rb_pointer1 = rb_start1;/* where we will copy it to during gc*/
 
 		mark_table = (int *)(rb_start1 + i);
 
@@ -1137,7 +1149,19 @@ enum type t;
 
 		heap_end += PAGESIZE*j;
 
-		core_end = heap_end;
+		/* When the program is re-loaded, the system initialization
+		   code may use malloc() before main() begins.  This
+		   happens in Linux.  We need to allow some heap expansion
+		   space for this.  One page is enough for Linux.
+		   Bill Metzenthen May95.
+		   */
+		if ( core_end < heap_end + PAGESIZE )
+		  {
+		    fprintf(stderr,
+			    "Not enough memory available for saved image\n");
+		    exit(1);
+		  }
+		core_end = heap_end + PAGESIZE;
 
 		for (i = 0;  i < maxpage;  i++)
 			if ((enum type)type_map[i] == t_contiguous)
@@ -1149,11 +1173,12 @@ enum type t;
 		ncbpage = 0;
 		ncb = 0;
 
-		if (sgc_enabled==0) holepage = new_holepage;
+                 /* hmm.... why is this test necessary.*/
+		if (sgc_enabled==0) {holepage = new_holepage;
+                                     nrbpage = INIT_NRBPAGE;}
 
-		nrbpage -= j;
-		if (nrbpage < 20)
-		  nrbpage = 20;
+		if (nrbpage < 0)
+			error("no relocatable pages left");
 
 		rb_start = heap_end + PAGESIZE*holepage;
 		rb_end = rb_start + PAGESIZE*nrbpage;
@@ -1242,7 +1267,7 @@ char *p;
 int s;
 { char *res = rb_pointer;
   char *q = rb_pointer1;
-  s = round_up(s);
+  s = ROUND_UP_PTR(s);
   rb_pointer += s;
   rb_pointer1 += s;
   
@@ -1263,8 +1288,8 @@ int s;
 	if (!MAYBE_DATA_P(p) || (enum type)type_map[page(p)] != t_contiguous)
 		return;
 	q = p + s;
-	x = (int *)(char *)((int)p&~3);
-	y = (int *)(char *)(((int)q+3)&~3);
+	x = (int *)ROUND_DOWN_PTR(p);
+	y = (int *)ROUND_UP_PTR(q);
 	for (;  x < y;  x++)
 		set_mark_bit(x);
 }
@@ -1280,7 +1305,7 @@ object x0;
 	else if (x0 == Cnil)
 		GBC(t_cons);
 	else
-		GBC(t_relocatable);
+		  { x0 = small_fixnum(1);	GBC(t_relocatable);}
 	RETURN1(x0);
 }
 
