@@ -41,7 +41,7 @@ void initialize_process();
 #endif
 #include "page.h"
 
-bool saving_system = FALSE;
+bool saving_system ;
 
 #ifdef BSD
 #include <sys/time.h>
@@ -260,6 +260,9 @@ char **argv, **envp;
 		if (type_of(sSAmultiply_stacksA->s.s_dbind)==t_fixnum)
 		  {multiply_stacks(fix(sSAmultiply_stacksA->s.s_dbind));
 		   goto  again;}
+#ifdef USE_DLOPEN
+ 	unlink_loaded_files();
+#endif			
 
 		exit(0);
 	}
@@ -306,7 +309,9 @@ void install_segmentation_catcher()
 }
 
 int catch_fatal=1;
+void
 error(s)
+char *s;
 {
         if (catch_fatal>0 && interrupt_enable )
 	  {catch_fatal = -1;
@@ -327,9 +332,13 @@ initlisp()
 {
 	int j;
 
-	if (NULL_OR_ON_C_STACK(&j) == 0)
+	if (NULL_OR_ON_C_STACK(&j) == 0
+	    || NULL_OR_ON_C_STACK(Cnil) != 0
+	    || (((unsigned long )core_end) !=0
+	        && NULL_OR_ON_C_STACK(core_end) != 0))
 	  { /* check person has correct definition of above */
-	    abort();}
+	    error("NULL_OR_ON_C_STACK macro invalid");
+	  }
 	init_alloc();
 
 	Cnil_body.t = (short)t_symbol;
@@ -551,7 +560,7 @@ va_dcl
 	exit(exit_code);
 #endif
 
-	RETURN(1,int,exit_code,);
+	RETURN(1,int,exit_code, 0); 
 }
 
 c_trace()
@@ -624,7 +633,9 @@ siLcatch_fatal(i)
  return Cnil;}
 
 
+void
 siLreset_stack_limits(arg)
+int arg;
 {
 	check_arg(0);
 	if(catch_fatal <0) catch_fatal=1;
