@@ -2,16 +2,16 @@
 NewInit(){
 
 DEFUNO("BYE",int,fLbye,LISP
-   ,0,1,0    ,II,OO,OO,OO,Lby,"")
+   ,0,1,0 ,II,OO,OO,OO,Lby,"")
 DEFUNO("IDENTITY",object,fLidentity,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lidentity,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lidentity,"")
 DEFUNO("LISP-IMPLEMENTATION-VERSION",object,fLlisp_implementation_version,LISP
-   ,0,0,0    ,OO,OO,OO,OO,Llisp_implementation_version,"")
+   ,0,0,0 ,OO,OO,OO,OO,Llisp_implementation_version,"")
 DEFVAR("*LISP-MAXPAGES*",sSAlisp_maxpagesA,SI,make_fixnum(real_maxpage),"")
 DEFVAR("*SYSTEM-DIRECTORY*",sSAsystem_directoryA,SI,make_simple_string(system_directory),"")
-DEFVAR("*MULTIPLY-STACKS*",sSAmultiply_stacksA,SI,		((object)&Cnil_body) ,"")
+DEFVAR("*MULTIPLY-STACKS*",sSAmultiply_stacksA,SI,((object)&Cnil_body) ,"")
 DEF_ORDINARY("TOP-LEVEL",sStop_level,SI,"")
-DEFVAR("*COMMAND-ARGS*",sSAcommand_argsA,SI,		((object)&Cnil_body)  ,"")
+DEFVAR("*COMMAND-ARGS*",sSAcommand_argsA,SI,((object)&Cnil_body)  ,"")
 DEFVAR("*AFTER-GBC-HOOK*",sSAafter_gbc_hookA,SI,((object)&Cnil_body)  ,"")
 DEFVAR("*IGNORE-MAXIMUM-PAGES*",sSAignore_maximum_pagesA,SI,((object)&Ct_body)  ,"")
 DEFUN("ALLOCATED",object,fSallocated,SI
@@ -36,6 +36,7 @@ DEFUNO("GET-HOLE-SIZE",object,fSget_hole_size,SI
    ,0,0,0 ,OO,OO,OO,OO,siLget_hole_size,"")
 DEFUNO("SET-HOLE-SIZE",object,fSset_hole_size,SI
    ,1,2,0 ,OI,IO,OO,OO,siLset_hole_size,"")
+DEFUN("STATICP",object,fSstaticp,SI,1,1,0 ,OO,OO,OO,OO,"Tell if the string or vector is static")
 DEFUNO("GBC",object,fLgbc,LISP
    ,1,1,0 ,OO,OO,OO,OO,Lgbc,"")
 DEFVAR("*NOTIFY-GBC*",sSAnotify_gbcA,SI,((object)&Cnil_body) ,"")
@@ -98,16 +99,16 @@ DEF_ORDINARY("PLUSP",sLplusp,LISP,"")
 DEFCONST("CHAR-SIZE",sSchar_size,SI,(object)(small_fixnum_table+1024 +( 8  )) ,"Size in bits of a character")
 DEFCONST("SHORT-SIZE",sSshort_size,SI,(object)(small_fixnum_table+1024 +( 8 *sizeof(short) )) ,"Size in bits of a short integer")
 DEFUNO("FUNCALL",object,fLfuncall,LISP
-   ,1,63 ,0    ,OO,OO,OO,OO,Lfuncall,"")
+   ,1,63 ,0 ,OO,OO,OO,OO,Lfuncall,"")
 DEFUNO("APPLY",object,fLapply,LISP
-   ,2,63 ,0    ,OO,OO,OO,OO,Lapply,"")
+   ,2,63 ,0 ,OO,OO,OO,OO,Lapply,"")
 DEFUNO("EVAL",object,fLeval,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Leval,"")
+   ,1,1,0 ,OO,OO,OO,OO,Leval,"")
 DEFUNO("CONSTANTP",object,fLconstantp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lconstantp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lconstantp,"")
 DEF_ORDINARY("LAMBDA-BLOCK-EXPANDED",sSlambda_block_expanded,SI,"")
-DEFVAR("*BREAK-POINTS*",sSAbreak_pointsA,SI,		((object)&Cnil_body) ,"")
-DEFVAR("*BREAK-STEP*",sSAbreak_stepA,SI,		((object)&Cnil_body) ,"")
+DEFVAR("*BREAK-POINTS*",sSAbreak_pointsA,SI,((object)&Cnil_body) ,"")
+DEFVAR("*BREAK-STEP*",sSAbreak_stepA,SI,((object)&Cnil_body) ,"")
 DEFUNO("MACROEXPAND",object,fLmacroexpand,LISP
    ,1,2,0    ,OO,OO,OO,OO,Lmacroexpand,"")
 DEF_ORDINARY("FUNCALL",sLfuncall,LISP,"")
@@ -115,65 +116,67 @@ DEFVAR("*MACROEXPAND-HOOK*",sLAmacroexpand_hookA,LISP,sLfuncall,"")
 DEF_ORDINARY("DEFMACRO*",sSdefmacroA,SI,"")
 DEFVAR("*INHIBIT-MACRO-SPECIAL*",sSAinhibit_macro_specialA,SI,		((object)&Cnil_body) ,"")
 DEFUN("NULL",object,fLnot,LISP
-   ,1,1,0    ,OO,OO,OO,OO,"")
+   ,1,1,0 ,OO,OO,OO,OO,"")
 DEFUNO("NOT",object,fLnot,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lnull,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lnull,"")
 DEFUNO("SYMBOLP",object,fLsymbolp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lsymbolp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lsymbolp,"")
 DEFUNO("ATOM",object,fLatom  ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Latom  ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Latom  ,"")
 DEFUNO("CONSP",object,fLconsp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lconsp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lconsp,"")
 DEFUNO("LISTP",object,fLlistp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Llistp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Llistp,"")
 DEFUNO("NUMBERP",object,fLnumberp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lnumberp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lnumberp,"")
 DEFUNO("INTEGERP",object,fLintegerp ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lintegerp ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lintegerp ,"")
 DEFUNO("RATIONALP",object,fLrationalp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lrationalp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lrationalp,"")
+DEFUN("REALP",object,fLrealp,LISP
+   ,1,1,0 ,OO,OO,OO,OO,"")
 DEFUNO("FLOATP",object,fLfloatp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lfloatp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lfloatp,"")
 DEFUNO("COMPLEXP",object,fLcomplexp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lcomplexp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lcomplexp,"")
 DEFUNO("CHARACTERP",object,fLcharacterp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lcharacterp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lcharacterp,"")
 DEFUNO("STRINGP",object,fLstringp ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lstringp ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lstringp ,"")
 DEFUNO("BIT-VECTOR-P",object,fLbit_vector_p,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lbit_vector_p,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lbit_vector_p,"")
 DEFUNO("VECTORP",object,fLvectorp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lvectorp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lvectorp,"")
 DEFUNO("SIMPLE-STRING-P",object,fLsimple_string_p,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lsimple_string_p,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lsimple_string_p,"")
 DEFUNO("SIMPLE-BIT-VECTOR-P",object,fLsimple_bit_vector_p ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lsimple_bit_vector_p ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lsimple_bit_vector_p ,"")
 DEFUNO("SIMPLE-VECTOR-P",object,fLsimple_vector_p ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lsimple_vector_p ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lsimple_vector_p ,"")
 DEFUNO("ARRAYP",object,fLarrayp ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Larrayp ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Larrayp ,"")
 DEFUNO("PACKAGEP",object,fLpackagep ,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lpackagep ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lpackagep ,"")
 DEFUNO("FUNCTIONP",object,fLfunctionp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lfunctionp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lfunctionp,"")
 DEFUNO("COMPILED-FUNCTION-P",object,fLcompiled_function_p,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lcompiled_function_p,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lcompiled_function_p,"")
 DEFUNO("COMMONP",object,fLcommonp,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lcommonp,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lcommonp,"")
 DEFUNO("EQ",object,fLeq,LISP
-   ,2,2,0    ,OO,OO,OO,OO,Leq,"")
+   ,2,2,0 ,OO,OO,OO,OO,Leq,"")
 DEFUNO("EQL",object,fLeql,LISP
-   ,2,2,0    ,OO,OO,OO,OO,Leql,"")
+   ,2,2,0 ,OO,OO,OO,OO,Leql,"")
 DEFUNO("EQUAL",object,fLequal,LISP
-   ,2,2,0    ,OO,OO,OO,OO,Lequal,"")
+   ,2,2,0 ,OO,OO,OO,OO,Lequal,"")
 DEFUNO("EQUALP",object,fLequalp,LISP
-   ,2,2,0    ,OO,OO,OO,OO,Lequalp,"")
+   ,2,2,0 ,OO,OO,OO,OO,Lequalp,"")
 DEFUNO("CONTAINS-SHARP-COMMA",object,fScontains_sharp_comma,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLcontains_sharp_comma,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLcontains_sharp_comma,"")
 DEFUNO("SPICEP",object,fSspicep  ,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLspicep  ,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLspicep  ,"")
 DEFUNO("FIXNUMP",object,fSfixnump,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLfixnump,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLfixnump,"")
 DEFUNO("SET",object,fLset,LISP
    ,2,2,0    ,OO,OO,OO,OO,Lset,"")
 DEFUNO("FSET",object,fSfset,SI
@@ -211,21 +214,21 @@ DEFUNO("ERROR-SET",object,fSerror_set,SI
    ,1,1,0 ,OO,OO,OO,OO,siLerror_set,
        "Evaluates the FORM in the null environment.  If the evaluation of the FORM has successfully completed, SI:ERROR-SET returns NIL as the first value and the result of the evaluation as the rest of the values.  If, in the course of the evaluation, a non-local jump from the FORM is atempted, SI:ERROR-SET traps the jump and returns the corresponding jump tag as its value.")
 DEFUNO("MC",object,fSmc,SI
-   ,2,2,0    ,OO,OO,OO,OO,siLmc,"")
+   ,2,2,0 ,OO,OO,OO,OO,siLmc,"")
 DEFUNO("MFSFUN",object,fSmfsfun,SI
-   ,3,3,0    ,OO,OO,OO,OO,siLmfsfun,"")
+   ,3,3,0 ,OO,OO,OO,OO,siLmfsfun,"")
 DEFUNO("MFVFUN",object,fSmfvfun,SI
-   ,3,3,0    ,OO,OO,OO,OO,siLmfvfun,"")
+   ,3,3,0 ,OO,OO,OO,OO,siLmfvfun,"")
 DEFUNO("MFVFUN-KEY",object,fSmfvfun_key,SI
-   ,4,4,0    ,OO,OO,OO,OO,siLmfvfun_key,"")
+   ,4,4,0 ,OO,OO,OO,OO,siLmfvfun_key,"")
 DEFUNO("MF",object,fSmf,SI
-   ,2,2,0    ,OO,OO,OO,OO,siLmf,"")
+   ,2,2,0 ,OO,OO,OO,OO,siLmf,"")
 DEFUNO("MM",object,fSmm,SI
-   ,2,2,0    ,OO,OO,OO,OO,siLmm,"")
+   ,2,2,0 ,OO,OO,OO,OO,siLmm,"")
 DEFUNO("COMPILED-FUNCTION-NAME",object,fScompiled_function_name,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLcompiled_function_name,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLcompiled_function_name,"")
 DEFUNO("TURBO-CLOSURE",object,fSturbo_closure,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLturbo_closure,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLturbo_closure,"")
 DEFUNO("SPECIALP",object,fSspecialp,SI
    ,1,1,0 ,OO,OO,OO,OO,siLspecialp,"")
 DEF_ORDINARY("DEBUG",sSdebug,SI,"")
@@ -243,6 +246,8 @@ DEF_ORDINARY("INTERNAL",sKinternal,KEYWORD,"")
 DEF_ORDINARY("NICKNAMES",sKnicknames,KEYWORD,"")
 DEF_ORDINARY("USE",sKuse,KEYWORD,"")
 DEFVAR("*PACKAGE*",sLApackageA,LISP,lisp_package,"")
+DEFUN("ALLOCATE-BIGGER-FIXNUM-RANGE",object,fSallocate_bigger_fixnum_range,
+      SI,2,2,0 ,OI,IO,OO,OO,"")
 DEFUNO("NTH",object,fLnth,LISP,2,2,NONE,OI,OO,OO,OO,Lnth,"")
 DEFUN("FIRST",object,fLfirst,LISP,0,0,NONE,OO,OO,OO,OO,"")
 DEFUNO("SECOND",object,fLsecond,LISP,1,1,NONE,OO,OO,OO,OO,Lsecond,"")
@@ -254,6 +259,10 @@ DEFUNO("SEVENTH",object,fLseventh,LISP,1,1,NONE,OO,OO,OO,OO,Lseventh,"")
 DEFUNO("EIGHTH",object,fLeighth,LISP,1,1,NONE,OO,OO,OO,OO,Leighth,"")
 DEFUNO("NINTH",object,fLninth,LISP,1,1,NONE,OO,OO,OO,OO,Lninth,"")
 DEFUNO("TENTH",object,fLtenth,LISP,1,1,NONE,OO,OO,OO,OO,Ltenth,"")
+DEFUN("NEXT-HASH-TABLE-ENTRY",object,fSnext_hash_table_entry,SI,2,2,NONE,OO,OO,OO,OO,"For HASH-TABLE and for index I return three values: NEXT-START, the next KEY and its  VALUE.   NEXT-START will be -1 if there are no more entries, otherwise it will be a value suitable for passing as an index")
+DEFUN("HASH-TABLE-TEST",object,fLhash_table_test,LISP,1,1,NONE,OO,OO,OO,OO,
+ "Given a HASH-TABLE return a symbol which specifies the function used in its test")
+DEFUN("HASH-TABLE-SIZE",int,fLhash_table_size,LISP,1,1,NONE,IO,OO,OO,OO,"")
 DEFCONST("ARRAY-RANK-LIMIT", sLarray_rank_limit, LISP,
 	 make_fixnum(63 ),"")
 DEFCONST("ARRAY-DIMENSION-LIMIT", sLarray_dimension_limit,
@@ -412,45 +421,45 @@ DEFVAR("*INDENT-FORMATTED-OUTPUT*",sSAindent_formatted_outputA,SI,((object)&Cnil
 DEFUNO("DELETE-FILE",object,fLdelete_file,LISP
    ,1,1,0    ,OO,OO,OO,OO,Ldelete_file,"")
 DEFUNO("ERROR",object,fLerror,LISP
-   ,1,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,Lerror,"")
+   ,1,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lerror,"")
 DEFUNO("CERROR",object,fLcerror,LISP
-   ,2,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,Lcerror,"")
+   ,2,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lcerror,"")
 DEFUNO("IHS-TOP",object,fSihs_top,SI
-   ,0,0,0    ,OO,OO,OO,OO,siLihs_top,"")
+   ,0,0,0 ,OO,OO,OO,OO,siLihs_top,"")
 DEFUNO("IHS-FUN",object,fSihs_fun,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLihs_fun,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLihs_fun,"")
 DEFUNO("IHS-VS",object,fSihs_vs,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLihs_vs,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLihs_vs,"")
 DEFUNO("FRS-TOP",object,fSfrs_top,SI
-   ,0,0,0    ,OO,OO,OO,OO,siLfrs_top,"")
+   ,0,0,0 ,OO,OO,OO,OO,siLfrs_top,"")
 DEFUNO("FRS-VS",object,fSfrs_vs,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLfrs_vs,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLfrs_vs,"")
 DEFUNO("FRS-BDS",object,fSfrs_bds,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLfrs_bds,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLfrs_bds,"")
 DEFUNO("FRS-CLASS",object,fSfrs_class,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLfrs_class,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLfrs_class,"")
 DEFUNO("FRS-TAG",object,fSfrs_tag,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLfrs_tag,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLfrs_tag,"")
 DEFUNO("FRS-IHS",object,fSfrs_ihs,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLfrs_ihs,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLfrs_ihs,"")
 DEFUNO("BDS-TOP",object,fSbds_top,SI
-   ,0,0,0    ,OO,OO,OO,OO,siLbds_top,"")
+   ,0,0,0 ,OO,OO,OO,OO,siLbds_top,"")
 DEFUNO("BDS-VAR",object,fSbds_var,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLbds_var,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLbds_var,"")
 DEFUNO("BDS-VAL",object,fSbds_val,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLbds_val,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLbds_val,"")
 DEFUNO("VS-TOP",object,fSvs_top,SI
-   ,0,0,0    ,OO,OO,OO,OO,siLvs_top,"")
+   ,0,0,0 ,OO,OO,OO,OO,siLvs_top,"")
 DEFUNO("VS",object,fSvs,SI
-   ,1,1,0    ,OO,OO,OO,OO,siLvs,"")
+   ,1,1,0 ,OO,OO,OO,OO,siLvs,"")
 DEFUNO("SCH-FRS-BASE",object,fSsch_frs_base,SI
-   ,2,2,0    ,OO,OO,OO,OO,siLsch_frs_base,"")
+   ,2,2,0 ,OO,OO,OO,OO,siLsch_frs_base,"")
 DEFUNO("INTERNAL-SUPER-GO",object,fSinternal_super_go,SI
-   ,3,3,0    ,OO,OO,OO,OO,siLinternal_super_go,"")
+   ,3,3,0 ,OO,OO,OO,OO,siLinternal_super_go,"")
 DEF_ORDINARY("UNIVERSAL-ERROR-HANDLER",sSuniversal_error_handler,SI
 	     ,"Redefined in lisp, this is the function called by the internal error handling mechanism.  Args:  (error-name correctable function-name    continue-format-string error-format-string    &rest args)")
 DEFUNO("UNIVERSAL-ERROR-HANDLER",object,fSuniversal_error_handler,SI
-   ,5,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,
+   ,5,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,
        siLuniversal_error_handler,"")
 DEF_ORDINARY("TERMINAL-INTERRUPT",sSterminal_interrupt,SI,"")
 DEF_ORDINARY("WRONG-TYPE-ARGUMENT",sKwrong_type_argument,KEYWORD,"")
@@ -465,14 +474,16 @@ DEF_ORDINARY("INVALID-FUNCTION",sKinvalid_function,KEYWORD,"")
 DEF_ORDINARY("CATCH",sKcatch,KEYWORD,"")
 DEF_ORDINARY("PROTECT",sKprotect,KEYWORD,"")
 DEF_ORDINARY("CATCHALL",sKcatchall,KEYWORD,"")
-DEFVAR("*DEFAULT-TIME-ZONE*",sSAdefault_time_zoneA,SI,make_fixnum((-9) ),"")
+DEFUNO("GET-UNIVERSAL-TIME",object,fLget_universal_time,LISP
+   ,0,0,0,OO,OO,OO,OO,Lget_universal_time,"")
+DEFVAR("*DEFAULT-TIME-ZONE*",sSAdefault_time_zoneA,SI,make_fixnum((-9)),"")
 DEFUN("GETPID",int,fSgetpid,SI,0,0,0    ,IO,OO,OO,OO,
       "getpid  returns  the  process  ID  of the current process")
-DEFUN("USE-FAST-LINKS",object,fSuse_fast_links,SI,1,2,0    ,OO,OO,OO,OO,
+DEFUN("USE-FAST-LINKS",object,fSuse_fast_links,SI,1,2,0 ,OO,OO,OO,OO,
 
       "Usage: (use-fast-links {nil,t} &optional fun) turns on or off the fast linking depending on FLAG, so that things will either go faster, or turns it off so that stack information is kept.  If SYMBOL is supplied and FLAG is nil, then this function is deleted from the fast links")
 DEF_ORDINARY("CDEFN",sScdefn,SI,"")
-DEFVAR("*LINK-ARRAY*",sLAlink_arrayA,LISP,		((object)&Cnil_body) ,"")
+DEFVAR("*LINK-ARRAY*",sLAlink_arrayA,LISP,((object)&Cnil_body) ,"")
 DEFUNO("PROFILE",object,fSprofile,SI
    ,2,2,0 ,OO,OO,OO,OO,siLprofile,
        "Sets up profiling with START-ADDRESS and  SCALE where scale is   between 0 and 256")
@@ -493,13 +504,9 @@ DEF_ORDINARY("SIGIO-INTERRUPT",sSsigio_interrupt,SI,"")
 DO_INIT(init_safety();)
 
 DEFUN("SIGNAL-SAFETY-REQUIRED",int,sSsignal_safety_required,SI,2,2,
-      NONE,II,IO,OO,OO,
-      "Set the safety level required for handling SIGNO to SAFETY, or if \
-SAFETY is negative just return the current safety level for that \
-signal number.  Value of 1 means allow interrupt at any place not \
-specifically marked in the code as bad, and value of 2 means allow it \
-only in very SAFE places.")
-DEFUN("ALLOW-SIGNAL",int,fSallow_signal,SI,1,1,NONE,II,OO,OO,OO,
+      0 ,II,IO,OO,OO,
+      "Set the safety level required for handling SIGNO to SAFETY, or if SAFETY is negative just return the current safety level for that signal number.  Value of 1 means allow interrupt at any place not specifically marked in the code as bad, and value of 2 means allow it only in very SAFE places.")
+DEFUN("ALLOW-SIGNAL",int,fSallow_signal,SI,1,1,0 ,II,OO,OO,OO,
       "Install the default signal handler on signal N")
 DEFUN("INITFUN",object,fSinitfun,SI,3,63 ,0 ,OO,OO,OO,OO,
       "Store a compiled function on SYMBOL whose body is in the VV array at INDEX, and whose argd descriptor is ARGD.  If more arguments IND1, IND2,.. are supplied these are indices in the VV array for the environment of this closure.")
