@@ -30,17 +30,24 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-/* #include <string.h> */
+#ifdef __STDC__
+#include <string.h> 
+#endif
 
 # include <netdb.h> 
 
 #include <sys/time.h>
+#ifndef NO_UNISTD_H
 #include <unistd.h>
+#endif
 #include <fcntl.h>
 /*#include <signal.h> */
 
 #include <errno.h> 
 
+void write_timeout_error();
+void connection_failure();
+
 
 #define BIND_MAX_RETRY		128
 #define BIND_ADDRESS_INCREMENT	16
@@ -183,7 +190,7 @@ lisp_copy_to_null_terminated(string,buf,n)
      object string;
 { if(type_of(string) != t_string
       && type_of(string) != t_symbol)
-    FEerror("Need to give symbol or string");
+    FEerror("Need to give symbol or string",0);
   if (string->st.st_fillp +1 > n)
     { buf= (void *)malloc(string->st.st_fillp +1);
     }
@@ -198,7 +205,6 @@ DEFUN("HOSTNAME-TO-HOSTID",object,fShostname_to_hostid,SI,1,1,
       NONE,OO,OO,OO,OO,"")(host)
 {
   struct hostent *h;
-  char *host_name ;
   char buf[300];
   char *p;
   p = lisp_copy_to_null_terminated(host,buf,sizeof(buf));
@@ -336,7 +342,7 @@ object the_code;
   int downcase ;
   int do_end_quote = 0;
   if(type_of(str)!=t_string)
-    FEerror("Must be given string with fill pointer");
+    FEerror("Must be given string with fill pointer",0);
   if (t==t_symbol) downcase=1;
   else downcase=0;
   
@@ -428,6 +434,7 @@ object the_code;
    }
 }
 
+void
 not_defined_for_os()
 { FEerror("Function not defined for this operating system",0);}
 
@@ -436,13 +443,17 @@ DEFUN("SET-SIGIO-FOR-FD",object,fSset_sigio_for_fd,SI,1,1,NONE,OI,OO,OO,OO,"")
      (fd)
      int fd;
 { int flags;
+  /* for the moment we will use SIGUSR1 to notify, instead of depending on SIGIO,
+     since LINUX does not support the latter yet...
+     So right  now this does nothing... 
+  */   
 #if !defined(FASYNC) || !defined(SET_FD_TO_GIVE_SIGIO)
   not_defined_for_os();
-#else
   
 #ifdef SET_FD_TO_GIVE_SIGIO
   SET_FD_TO_GIVE_SIGIO(fd);
 #else
+  /* want something like this... but wont work on all machines. */
   flags = fcntl(fd,F_GETFL,0);
   if (flags == -1
       || ( flags |=  FASYNC , 0)
@@ -451,8 +462,10 @@ DEFUN("SET-SIGIO-FOR-FD",object,fSset_sigio_for_fd,SI,1,1,NONE,OI,OO,OO,OO,"")
     {perror("Could not set ASYNC IO for SIGIO:");
      return Cnil;}
 #endif
-  return (Ct);
 #endif
+
+  return (Ct);
+
 }
      
 DEFUN("RESET-STRING-INPUT-STREAM",object,fSreset_string_input_stream,SI,4,4,NONE,OO,OI,IO,OO,
@@ -491,16 +504,15 @@ DEFUN("CLEAR-CONNECTION-STATE",int,fSclear_connection_state,
  return n;
 }
 
+void
 write_timeout_error(s)
      char *s;
 {FEerror("Write timeout: ~s",1,make_simple_string(s));
 }
+
+void
 connection_failure(s)
      char *s;
 {FEerror("Connect failure: ~s",1,make_simple_string(s));
 }
 
-
-#ifdef HAVE_X11
-#include "clxsocket.c"
-#endif
